@@ -1,4 +1,4 @@
 """
 A module with various plotting utilities
 """
-from .plotutils import setfig
+from .plotutils import setfig,plot2dhist
